Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/mafw_tools/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/mafw_tools/file_tools.py | 44 | 0 | 0 | 24 | 0 | 100%
src/mafw_tools/generic_tools.py | 6 | 0 | 0 | 2 | 0 | 100%
src/mafw_tools/plotting_tools.py | 25 | 0 | 0 | 10 | 0 | 100%
Total | 75 | 0 | 0 | 36 | 0 | 100%

No items found using the specified filter.